"""
keyboard tags
"""
keyboard_press_key_error_tag = "keyboard press key error"
keyboard_release_key_error_tag = "keyboard release key error"
keyboard_type_key_error_tag = "keyboard type key error"
"""
mouse tags
"""
mouse_get_position_error_tag = "mouse get position error"
mouse_set_position_error_tag = "mouse set position error"
mouse_press_mouse_error_tag = "mouse press mouse error"
mouse_release_mouse_error_tag = "mouse release key error"
mouse_click_mouse_error_tag = "mouse click mouse error"
mouse_scroll_error_tag = "mouse scroll error"
"""
screen tags
"""
screen_get_size_error_tag = "screen get size error"
"""
table tags
"""
cant_find_key_error_tag = "can't find key error"
